@@ -1367,7 +1367,7 @@ class LaharFlowData(object):
 
         indx = np.sqrt((data['x_distance']-POI_xy[0])**2+(data['y_distance']-POI_xy[1])**2)<buffer
         
-        n = len(indx)
+        n = np.count_nonzero(indx)
 
         dt = [
             ('x_distance', np.float64),
